#Todo: allow for repeated measure contrasts
# Requires: gmodels

contrast = function(lm.obj, contr) {    
  # Pull the right variables out of the model
  lm.vars = attr(lm.obj$terms,'variables')
  var.nms = sapply(lm.vars[2:length(lm.vars)],function(x){x})
  
  pfrm = parent.frame()
  # Pull out data
  dnm = as.character(lm.obj$call$data)
  if(length(dnm) == 0) {dat = lapply(var.nms,eval); names(dat) = sapply(var.nms,function(x) {paste(x[2],x[1],x[3],sep='')})}
  else {dat = sapply(var.nms,function(x){eval(as.name(dnm),pfrm)[as.character(x)]})}
  
  # Check for numerical / covariates
  dcls = sapply(dat,class)[-1]
  
  facts = names(dcls[which(dcls == 'factor' | dcls == 'character')])
  covs = names(dcls[which(dcls != 'factor' & dcls != 'character')])
  
  if(length(facts) == 0) {print('Contrast requires model to contain factors'); return(invisible(NULL))}
  
  # Test to be sure that contrasts match with model factors
  nfact = length(dim(contr))
  if(nfact==0) {nfact = 1}
  if(nfact != (length(facts))) {print('Contrast matrix dimensions unequal to number of factors'); return(invisible(NULL))}
  if(nfact > 1) {
    for(i in 1:nfact) {
      if (length(levels(dat[[facts[i]]])) != dim(contr)[i]) {
        lname = facts[i]
        print(paste("Contrast dimensions for factor ",lname," not equal to number of levels",sep="'"))
        return(invisible(NULL))
      }
    }
  } else {
    if(length(levels(dat[[facts[1]]])) != length(contr)) {
      lname = facts[1]
      print(paste("Contrast dimensions for factor ",lname," not equal to number of levels",sep="'"))
      return(invisible(NULL))
    }
  }
  
  # Test for appropriate contrasts & normalize
  if(sum(contr) != 0) {print('Contrasts do not sum to 0'); return(invisible(NULL))}
  if(sum(abs(contr))==0) {print('No contrast values given'); return(invisible(NULL))}
  contr = 2*contr/(sum(abs(contr)))
  
  # Create the new model  
  flat.fact = do.call('interaction',dat[facts])
  mod.form = dat[[1]] ~ 1
  for(cv in covs) {mod.form = update(mod.form, ~ . + dat[cv][[1]])}
  mod.form = update(mod.form, ~ . + flat.fact)
  new.mod = lm(mod.form)
  
  # Make the contrast & return
  flat.contr = as.vector(contr)
  ctrst = fit.contrast(new.mod,'flat.fact',flat.contr)
  dimnames(ctrst)[[1]] = 'Contrast'
  return(ctrst)
}

getContrastMatrix = function(lm.obj) {
  # Pull the right variables out of the model
  lm.vars = attr(lm.obj$terms,'variables')
  var.nms = sapply(lm.vars[2:length(lm.vars)],function(x){x})
  
  if(length(lm.obj$call$data)==0) {var.nms = sapply(var.nms,function(x) {paste(x[2],x[1],x[3],sep='')})}
  
  # Get interaction levels
  facts = sapply(var.nms[2:length(var.nms)],function(x){lm.obj$model[as.character(x)]})
  dcls = sapply(facts,class)
  facts = facts[which(dcls == 'factor' | dcls == 'character')]
  
  if(length(lm.obj$call$data)==0) {names(facts) = var.nms[2:length(var.nms)]}
  lvs = levels(do.call('interaction',facts))
  
  # Form the return matrix
  m.ret = array(0,sapply(facts,function(x){length(levels(x))}))
  dnms = lapply(facts,levels)
  
  if(class(dnms) == 'matrix') {
    
  }
  
  dimnames(m.ret) = dnms
  return(m.ret)
}
