se = function(x, na.rm = FALSE) {
  n = ifelse(na.rm,sum(!is.na(x)),length(x))
  return(sd(x,na.rm)/sqrt(n))
}

twoway.aggregate = function(response, factor1, factor2, func = mean) {
  if(class(factor1) != 'factor') {factor1 = as.factor(factor1)}
  if(class(factor2) != 'factor') {factor2 = as.factor(factor2)}
  
  agg.tab = aggregate(response,list(factor1,factor2),func)
  names(agg.tab) = c('Factor1','Factor2','Summary')
  ref.tab = with(agg.tab,xtabs(Summary~Factor1+Factor2))
  return(ref.tab)
}

power.test = function(mu.null, mu.real, sigma, n = NULL, power = NULL, alpha = 0.05) {
  if((is.null(n) & is.null(power)) | (!is.null(n) & !is.null(power))) {
    writeLines('power.test requires exactly one of either n or power')
    return(invisible(NULL))
  }
  e.size = abs((mu.real-mu.null)/sigma) # Effect size
  z.alpha = qnorm(1-alpha/2) # Critical z-score given alpha
  
  if(is.null(n)) { # Solve for n
    return(ceiling(((qnorm(power)+z.alpha)/e.size)^2))
  }
  if(is.null(power)) { # Solve for power
    return(pnorm(e.size*sqrt(n)-z.alpha))
  }
  return(invisible(NULL))
}

cohens.f = function(lm.obj, weighted = F) {
  # Get the error variance
  sum.obj = summary(lm.obj)
  errvar = sum.obj$sigma^2
  
  # Pull the right variables out of the model
  lm.vars = attr(lm.obj$terms,'variables')
  var.nms = sapply(lm.vars[2:length(lm.vars)],function(x){x})
  pfrm = parent.frame()
  
  # Pull out data
  dnm = as.character(lm.obj$call$data)
  if(length(dnm) == 0) {dat = lapply(var.nms,eval); names(dat) = sapply(var.nms,function(x) {paste(x[2],x[1],x[3],sep='')})}
  else {dat = sapply(var.nms,function(x){eval(as.name(dnm),pfrm)[as.character(x)]})}
  
  # Check for numerical / covariates
  dcls = sapply(dat,class)[-1]
  if(any(dcls != 'factor' & dcls != 'character')) {writeLines("cohens.f not valid with continuous variables");return(invisible(NULL))}
  
  # Get means of the data
  agg = aggregate(dat[[1]],dat[2:length(dat)],mean)
  agg$pred = predict(lm.obj,agg)
  if(weighted) {
    agg$n = aggregate(dat[[1]],dat[2:length(dat)],length)
    grand.mean = (agg$pred * agg$n) / sum(agg$n)
    }
  else{grand.mean = mean(agg$pred)}
  
  k = dim(agg)[1]
  
  ss.dev = sum((agg$pred - grand.mean)^2)
  cf = sqrt(ss.dev / k / errvar)
  return(cf)
  
}