

print.permtest = function(object) {
  cl = object$call
  if(object$test.alt == 'two.sided') {alt = 'two-sided'}
  else if(object$test.alt == 'greater') {alt = 'one-sided (greater)'}
  else {alt = 'one-sided (less)'}
  writeLines(paste('Test type: ',object$type,'; ',alt,sep=''))
  writeLines(paste('Statistic function: ',cl[2],'\t\tShuffle function: ',cl[3],'\t\tData: ',cl[4],'\n',sep=''))
  writeLines(paste('Test statistic: ',signif(object$real.stat,5),'\np = ',signif(object$p.val,5),sep=''))
  writeLines(paste('Null distribution calculated with ',object$num.reps, ' samples',sep=''))
  
}

plot.permtest = function(x,y,...) {
  cl = match.call()
  nm = as.character(cl)[2]
  h = hist(x$shuf.stats,freq=F,xlab = 'Test statistic null distribution',ylab = 'Probability density',
           main = paste("Test statistic distribution for '",nm,"'",sep=''))
  mx = max(h$density)
  lines(x=c(x$real.stat,x$real.stat),y=c(0,mx*.9),lty=2)
  text(x$real.stat,mx,labels=paste('Real statistic: ',signif(x$real.stat,4),sep=''))
}

get.p.permtest = function(object) {
 return(object$p.val)
}

get.stat.permtest = function(object) {
  return(object$real.stat)
}

permute.test = function(data,test.stat,shuffler, n = 1000, alternative = "two.sided", try.parallel = c(TRUE,FALSE), ncores = getOption('mc.cores',2)) {
  
  match.arg(alternative,choices = c('two.sided','less','greater'))
  
  cl = match.call()
  real.t = test.stat(data)
  if(length(real.t) != 1) {
    stop('test.stat function must return only a single value')
  }
  
  if(missing(try.parallel)) try.parallel = (.Platform$OS.type != 'windows')
  
  if(try.parallel) {
    if(!require(parallel)) {
      wrn = ifelse(.Platform$OS.type != 'windows', 'No parallel package available - try install.package("parallel"); proceeding without parallelization',
                   'No parallel package available on Windows; proceeding without parallelization')
      warning(wrn)
      shuf.t = replicate(n,test.stat(shuffler(data)))
    } else {
      shuf.t = unlist(mclapply(1:n,function(i){test.stat(shuffler(data))},mc.cores=ncores))
    }
  } else {
    shuf.t = replicate(n,test.stat(shuffler(data)))
  }
  
  ecd = ecdf(shuf.t)
  if(alternative == 'less') {pv = ecd(real.t)}
  else if(alternative == 'greater') {pv = 1-ecd(real.t)}
  else if(alternative == 'two.sided' & (real.t >= mean(shuf.t))) {pv = 2*(1-ecd(real.t))}
  else if(alternative == 'two.sided' & (real.t < mean(shuf.t))) {pv = 2*ecd(real.t)}
  else {print('Error: Incorrect test criteria definition');return(invisible(NULL))}
  ret = list(call=cl,real.stat = real.t,shuf.stats= shuf.t, num.reps = n, p.val = pv,test.alt = alternative,type='permutation')
  class(ret) = 'permtest'
  return(ret)
}

print.bootstrapped = function(object) {
  writeLines(paste('Bootstrapped ',sprintf("%1.0f%%",object$ci.range*100),' confidence interval: [',signif(object$conf.int[1],5),',',signif(object$conf.int[2],5),']',sep=''))
  writeLines(paste('Bias: ',signif(object$bias,5),sep=''))
  writeLines(paste('Simulation based on ',object$num.samp,' samples',sep=''))
  
}

plot.bootstrapped = function(object) {
  cl = match.call()
  nm = as.character(cl)[2]
  h = hist(object$data,plot=F)
  mx = max(h$counts)
  h=hist(object$data,freq = T, xlab = 'Bootstrapped test statistic',ylab ='Statistic frequency',
       main = paste("Bootstrapped test statistic distribution for '",nm,"'",sep=''),ylim= c(0,mx*1.1))
  lines(x=c(object$real.stat,object$real.stat),y=c(0,mx*1.02),lty=2)
  text(object$real.stat,mx*1.1,labels=paste('Real statistic: ',signif(object$real.stat,4),sep=''))
  
  lines(x=rep(object$conf.int[1],2),y=c(0,mx*1.02),lty=1)
  lines(x=rep(object$conf.int[2],2),y=c(0,mx*1.02),lty=1)
  text(object$conf.int[1],mx*1.05,labels=paste('Lower CI:',signif(object$conf.int[1],4)))
  text(object$conf.int[2],mx*1.05,labels=paste('Upper CI:',signif(object$conf.int[2],4)))
}


bootstrap.CI = function(data, test.stat,shuffler = resample.data, n = 1000, conf.int = 0.95, try.parallel = c(TRUE,FALSE), ncores = getOption('mc.cores',2)) {
  
  real = test.stat(data)
  if(length(real) != 1) {
    stop('test.stat function must return only a single value')
  }
  
  if(missing(try.parallel)) try.parallel = (.Platform$OS.type != 'windows')
  
  if(try.parallel) {
    if(!require(parallel)) {
      wrn = ifelse(.Platform$OS.type != 'windows', 'No parallel package available - try install.package("parallel"); proceeding without parallelization',
                   'No parallel package available on Windows; proceeding without parallelization')
      warning(wrn)
      shuf.dist = replicate(n,test.stat(shuffler(data)))
    } else {
      shuf.dist = unlist(mclapply(1:n,function(i){test.stat(shuffler(data))},mc.cores=ncores))
    }
  } else {
    shuf.dist = replicate(n,test.stat(shuffler(data)))
  }
    
  rem = (1-conf.int)/2
  ci = quantile(shuf.dist,c(rem,1-rem))
  
  ret = list(real.stat = real, conf.int = ci, mean = mean(shuf.dist), bias = real-mean(shuf.dist),
             ci.range = conf.int, num.samp = n, data = shuf.dist)
  class(ret) = 'bootstrapped'
  return(ret)
}

resample.data = function(data,...) UseMethod('resample.data',data)

resample.data.data.frame = function(data, const.categories = NULL, shuf.categories = NULL) {
  
  dattypes = sapply(data,class)
  
  if(missing(const.categories))
    const.categories = names(data)[dattypes == 'factor' | dattypes == 'character']
  if(missing(shuf.categories))
    shuf.categories = names(data)[dattypes == 'numeric' | dattypes == 'integer']
  
  data$inter = with(data, do.call(interaction, lapply(const.categories,function(x){eval(as.name(x))}),quote=T))
  sps = split(data,data$inter)
  
  sps = lapply(sps, function(x){x[sample.int(nrow(x),replace=T),]})
  ret = unsplit(sps,data$inter)
  rownames(ret) = NULL
  return(ret[c(const.categories,shuf.categories)])
}

resample.data.default = function(data) {
  return(sample(data,length(data),replace=T))
}
