\name{bootstrap.CI}
\alias{bootstrap.CI}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Get Bootstrapped Confidence Intervals
}
\description{
Uses bootstrapping methods to calculate confidence intervals of a test statistic
}
\usage{
bootstrap.CI(data, test.stat, shuffler = resample.data, n = 1000, conf.int = 0.95, try.parallel = c(TRUE,FALSE), ncores = getOption('mcCores',2))
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{a vector, list, or data frame of the observed data.}
  \item{test.stat}{a function that takes only the '\code{data}' as input and outputs a single value representing the test statistic of interest.}
  \item{shuffler}{a function that takes only the '\code{data}' as input and outputs the data in equivalent form, but resampled according to the logic of bootstrapping. Defaults to \code{\link{resample.data}}.}
  \item{n}{the number of samples to take. Defaults to 1000.}
  \item{conf.int}{the range of the confidence interval. Defaults to 0.95.}
  \item{try.parallel}{option to parallelize the bootstrapping. Defaults to \code{TRUE} for Unix platforms, but does not exist on Windows platforms and is therefore turned off.}
  \item{ncores}{number of cores to use for parallelization. Defaults to what is set in environment variable MC_CORES, or 2 cores if that is not set.}
}

\value{
Returns a 'bootstrapped' object. The values for this object can be observed using the "\code{print}" and "\code{plot}" methods.
}

\author{
Kevin A Smith}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{permute.test}}
\code{\link{resample.data}}
}
\examples{
# Use the built-in 'warpbreaks' data
dat = warpbreaks

# Function for the test statistic: std dev of error
wbSig = function(dat) {
  dat.lm = lm(breaks~wool*tension,data=dat)
  return(summary(dat.lm)$sigma)
}

bootstrap.CI(warpbreaks,wbSig)

}
