\name{contrast}
\alias{contrast}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Compute and test arbitrary contrasts for regression objects
}
\description{
Extends the \code{fit.contrast} function from \code{gmodels} to allow for easier use of contrasts in two-way (and more) ANOVAs.
}
\usage{
contrast(lm.obj, contr)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{lm.obj}{lm regression object for which the contrast will be computed}
  \item{contr}{a matrix of contrast values. Dimensionality should be equal to the number of factors in \code{lm.obj}}
}
\details{
The \code{contr} matrix must sum to zero and have at least two non-zero entries. It is also suggested that the matrix be well-formed (e.g. \code{sum(abs(contr)) == 2}), but if not, this function will coerce the matrix such that is becomes so. Creating a basic matrix for this purpose can be done with \code{getContrastMatrix}
}
\value{
Returns a matrix containing estimated coefficients, standard errors, t values, two-sided p-values.
}
\author{
Kevin A Smith
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{fit.contrast} \link{estimable} \link{getContrastMatrix}}
}
\examples{
# Set up the model (2-way in this case)
wb.lm = lm(breaks~wool*tension,data=warpbreaks)

# Get the empty contrast matrix and fill it
ctr = getContrastMatrix(wb.lm)

# Is the difference between low vs. med/high tension different for wools A & B?
ctr[1,1] = 1
ctr[1,2] = -1
ctr[1,3] = -1
ctr[2,1] = -1
ctr[2,2] = 1
ctr[2,3] = 1

# Run the contrast
contrast(wb.lm,ctr)
}

