\name{diagnostic.plot}
\alias{diagnostic.plot}
\title{
Creates diagnostic plots of lm objects to test for violations of assumptions
}
\description{
Creates diagnostic plots falling into three categories:
\enumerate{
  \item Nomality of error (qq plots and histograms of residuals)
  \item Heteroscedasticity of error (residuals vs. dependent variables, predictors, and time)
  \item Influence (Cook's D)
}
}
\usage{
diagnostic.plot(lm.obj, type = "all", predictor = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{lm.obj}{An lm object to do diagnostics on}
  \item{type}{The type of plot to create. Can be one of the following types (defaults to \code{"all"}):
  \tabular{ll}{
   \code{residuals} \tab a histogram of the residual error. \cr
   \code{qq} \tab a QQ plot of the residual error (same as \code{plot(lm.obj,which = 2)}). \cr
   \code{fitted} \tab plots residuals against fitted values (same as \code{plot(lm.obj,which = 1)}). \cr
   \code{predictor} \tab plots residuals against predictor values. Uses the predictors defined in the \code{predictor} argument. \cr
   \code{abs predictor} \tab the same as \code{"predictor"} except it plots against the absolute value of the residuals. \cr
   \code{time} \tab plots the residuals against the order in which they were entered. \cr
   \code{influence} \tab plots Cook's D for each point (same as \code{plot(lm.obj,which = 4)}). \cr
   \code{all} \tab plots all of the above except \code{"abs predictor"}. \cr
   }
  }
  \item{predictor}{the names of the predictor variable(s) to plot against. Only used if \code{type = "predictor"} or \code{type = "abs predictor"}; ignored otherwise. If not provided, plots against each predictor variable individually.}
}

\author{
Kevin A Smith
}
\seealso{
\code{\link{plot.lm}}
}
\examples{
carlm = lm(mpg ~ factor(cyl) + disp + wt,data = mtcars)

# Histogram of residuals
diagnostic.plot(carlm,"residuals")

# QQ plot of residuals
diagnostic.plot(carlm,"qq")

# Plot of fitted values vs. residuals
diagnostic.plot(carlm,"fitted")

# Plot 'disp' vs. residuals
diagnostic.plot(carlm,"predictor","disp")

# Plot 'wt' vs. absolute value of residuals
diagnostic.plot(carlm,"abs predictor","wt")

# Plot residuals vs. all predictors
diagnostic.plot(carlm,"predictor")

# Plot residuals vs. time
diagnostic.plot(carlm,"time")

# Plot the influence of each point
diagnostic.plot(carlm,"influence")

# Plot everything
diagnostic.plot(carlm)
}