\name{get.ci}
\alias{get.ci}
\alias{get.ci.lm}
\alias{get.ci.htest}
\alias{get.ci.bootstrapped}
\alias{get.ci.default}
\title{
Get the confidence interval(s) on parameter estimates for various statistical tests
}
\description{
Retrieves the confidence intervals on parameter estimates from hypothesis tests (htest) and lm objects
}
\usage{
get.ci(x, ...)

\method{get.ci}{default}(x,...)

\method{get.ci}{lm}(obj, conf.int = 0.95)
}
\arguments{
  \item{obj}{the statistical test object. \code{obj} must be one of the following types: \code{lm}, \code{htest}}
  \item{conf.int}{if an \code{lm} object is given, this provides the range of confidence required (e.g., a 95 percent confidence interval). Defaults to 0.95.}
}
\value{
The form of return depends on the type of object passed to the function:
  \item{lm}{a matrix of the parameter estimate and lower and upper bounds for each independent factor.}
  \item{htest}{the lower and upper bounds of the test parameter estimate.}
}
\author{
Kevin A Smith
}
\examples{
test_htest = t.test(mpg ~ factor(am),mtcars)
get.ci(test_htest)

test_lm = lm(mpg ~ factor(am),mtcars)
get.ci(test_lm)
get.ci(test_lm, conf.int = 0.99)
}
