\name{get.df}
\alias{get.df}
\alias{get.df.lm}
\alias{get.df.aov}
\alias{get.df.htest}
\alias{get.df.aovlist}
\alias{get.df.anova}
\alias{get.df.default}
\title{
Get degrees of freedom used for various statistical tests
}
\description{
Retrieves the degrees of freedom used for various types of common statistical test objects used in R
}
\usage{
get.df(x, ...)

\method{get.df}{default}(x,...)

\method{get.df}{lm}(obj, aov.type = FALSE)
}
\arguments{
  \item{obj}{the statistical test object. \code{obj} must be one of the following types: \code{lm}, \code{aov}, \code{htest}, \code{aovlist}, \code{anova}}
  \item{aov.type}{if an \code{lm} object is given, switching this to \code{TRUE} provides factor-level information rather than indicator variable-level. Identical to \code{get.df(anova(obj))}}
}
\value{
The form of return depends on the type of object passed to the function:
  \item{lm}{a vector of the two degrees of freedom for the omnibus F-test. For individual t-parameters, the second value is the degrees of freedom for the relevant t distribution.}
  \item{aov}{a data frame containing the two degrees of freedom for the F-test, where each factor/interaction is a separate row.}
  \item{htest}{a single value representing the degrees of freedom for the relevant test.}
  \item{aovlist}{a data frame just like \code{aov}, but collapsed across all \code{aov} objects in the list.}
  \item{anova}{a data frame just like \code{aov}}
}
\author{
Kevin A Smith
}
\examples{
test_htest = t.test(mpg ~ factor(am),mtcars)
get.df(test_htest)

test_lm = lm(mpg ~ factor(am),mtcars)
get.df(test_lm)
get.df(test_lm, TRUE)

test_aov = aov(mpg ~ factor(am),mtcars)
get.df(test_aov)
}
