\name{get.p}
\alias{get.p}
\alias{get.p.lm}
\alias{get.p.htest}
\alias{get.p.anova}
\alias{get.p.aov}
\alias{get.p.aovlist}
\alias{get.p.permtest}
\alias{get.p.TukeyHSD}
\alias{get.p.default}
\title{
Get the p-value(s) used for various statistical tests
}
\description{
Retrieves the p-value(s) used for various types of common statistical test objects used in R
}
\usage{
get.p(x, ...)

\method{get.p}{default}(x,...)

\method{get.p}{lm}(obj, aov.type = FALSE)
}
\arguments{
  \item{obj}{the statistical test object. \code{obj} must be one of the following types: \code{lm}, \code{aov}, \code{htest}, \code{aovlist}, \code{anova}}
  \item{aov.type}{if an \code{lm} object is given, switching this to \code{TRUE} provides factor-level information rather than indicator variable-level. Identical to \code{get.p(anova(obj))}}
}
\value{
The form of return depends on the type of object passed to the function:
  \item{lm}{a vector of the p-values for each of the indicator variable t-tests.}
  \item{aov}{a vector of the p-values for each of the factors/interactions, using Type I ANOVA.}
  \item{htest}{a single value representing the p-value for the relevant test.}
  \item{aovlist}{a vector just like \code{aov}, but collapsed across all \code{aov} objects in the list.}
  \item{anova}{a vector just like \code{aov}}
  \item{TukeyHSD}{a named vector with all pairwise comparisons.}
}
\author{
Kevin A Smith
}
\examples{
test_htest = t.test(mpg ~ factor(am),mtcars)
get.p(test_htest)

test_lm = lm(mpg ~ factor(am),mtcars)
get.p(test_lm)
get.p(test_lm, TRUE)

test_aov = aov(mpg ~ factor(am),mtcars)
get.p(test_aov)
}
