\name{get.stat}
\alias{get.stat}
\alias{get.stat.lm}
\alias{get.stat.htest}
\alias{get.stat.aov}
\alias{get.stat.aovlist}
\alias{get.stat.anova}
\alias{get.stat.default}
\alias{get.stat.permtest}
\title{
Get the test statistic(s) used for various statistical tests
}
\description{
Retrieves the test statistic(s) used for various types of common statistical test objects used in R
}
\usage{
get.stat(x, ...)

\method{get.stat}{default}(x,...)

\method{get.stat}{lm}(obj, omnibus = FALSE)
}
\arguments{
  \item{obj}{the statistical test object. \code{obj} must be one of the following types: \code{lm}, \code{aov}, \code{htest}, \code{aovlist}, \code{anova}}
  \item{omnibus}{if an \code{lm} object is given, switching this to \code{TRUE} provides the F-statistic for the omnibus test rather than individual t-statistics}
}
\value{
The form of return depends on the type of object passed to the function:
  \item{lm}{by default, a vector of the t-statistics for each of the indicator variable t-tests. If \code{omnibus=TRUE}, returns a single F-statistic for the omnibus test instead}
  \item{aov}{a vector of the F-statistics for each of the factors/interactions, using Type I ANOVA.}
  \item{htest}{a single value representing the statistic for the relevant test.}
  \item{aovlist}{a vector just like \code{aov}, but collapsed across all \code{aov} objects in the list.}
  \item{anova}{a vector just like \code{aov}}
}
\author{
Kevin A Smith
}
\examples{
test_htest = t.test(mpg ~ factor(am),mtcars)
get.stat(test_htest)

test_lm = lm(mpg ~ factor(am),mtcars)
get.stat(test_lm)
get.stat(test_lm, TRUE)

test_aov = aov(mpg ~ factor(am),mtcars)
get.stat(test_aov)
}
