\name{power.test}
\alias{power.test}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
One-Sample Statistical Power Test
}
\description{
Provides either (a) the power of a simple one-sample statistical test for a given number of observations, or (b) the number of observations needed to reach a given power level. Requires assumptions about the population means and standard deviations to function.
}
\usage{
power.test(mu.null, mu.real, sigma, n = NULL, power = NULL, alpha = 0.05)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mu.null}{the assumed population mean for the null hypothesis.}
  \item{mu.real}{the assumed population mean of the tested (treatment) group.}
  \item{sigma}{the assumed standard deviation of observations in the population.}
  \item{n}{the number of observations of the treatment group to be obtained. Providing this argument will get the power of the test.}
  \item{power}{the desired power level of the test. Providing this argument will get the number of observations required for this power.}
  \item{alpha}{the Type I (false positive) rate. Defaults to 0.05}
}
\details{
Only one of \code{n} or \code{power} should be provided as an argument, as this function solves for the other.
}

\value{
Returns a single number. If \code{n} is given as an argument, this is the power of the resulting test. If \code{power} is given, then the required number of observations are returned.
}

\author{
Kevin A Smith
}

\seealso{
\code{\link{z.test}}
}
\examples{
# First we define the hypothetical null and effect (an effect size of 1/3):
mu.null = 0
mu.eff = 5
sd.null = 15

# If we want to know the sample size required for 0.8 power, we write:
power.test(mu.null,mu.eff,sd.null,power = 0.8)

# And if we want to know the power with a sample size of 50:
power.test(mu.null,mu.eff,sd.null,n = 50)
}
